@@ -3,7 +3,8 @@
 #'
 #' @description Esta funcao possibilita a obtencao de medidas associadas aos
 #'   objetos em imagens binarias.
-#' @usage measure_image(img,noise=0,id=NULL,length= NULL,width =NULL)
+#' @usage measure_image(img,noise=0,id=NULL,length= NULL,width =NULL, splitConnected=FALSE,
+#' tolerance = 1, ext = 1,  plot= TRUE)
 #' @param img    :Este objeto deve ser obrigatoriamente uma matriz binaria,
 #'   contendo os valores 0 (pixels do background) e 1 (pixels do foreground)).
 #' @param noise    : E o numero de pixeis a partir do qual a funcao nao
@@ -16,7 +17,18 @@
 #' @param length    :Comprimento do objeto de referencia ou da imagem em
 #'   centimetros.
 #' @param width    :Altura do objeto de referencia ou da imagem em centimetros.
-
+#' @param splitConnected :Variavel do tipo logico. Se TRUE objetos encostados
+#' serao considerados diferentes.
+#' @param tolerance The minimum height of the object in the units of image
+#'   intensity between its highest point (seed) and the point where it contacts
+#'   another object (checked for every contact pixel). If the height is smaller
+#'   than the tolerance, the object will be combined with one of its neighbors,
+#'   which is the highest. Tolerance should be chosen according to the range of
+#'   x. Default value is 1, which is a reasonable value if x comes from distmap.
+#' @param ext Radius of the neighborhood in pixels for the detection of
+#'   neighboring objects. Higher value smoothes out small objects.
+#' @param  plot Indica se sera apresentada (TRUE) ou nao (FALSE) (default) a
+#'   imagem segmentada
 #' @return Retorna as cordendas de cada objeto, sua area, perimetro, ...
 #' @seealso  \code{\link{segmentation_logit}}
 
@@ -30,7 +42,7 @@
 #'#Carregar imagem de exemplo
 #'im=read_image(example_image(2))
 #'##mostrar imagem
-#'plot(im)
+#'plot_image(im)
 
 #'
 #'#Selecionando o melhor indice para a segmentacao da folha
@@ -41,7 +53,7 @@
 #'
 #'#O canal azul possibilita maior contraste
 #'#O limiar pode ser um valor escolhido aleatoriamente (por exemplo: 0.6)
-#'MatrizSegmentada=segmentation(b,treshold = 0.30,fillHull = TRUE,
+#'MatrizSegmentada=segmentation(b,threshold = 0.40,fillHull = TRUE,
 #'selectHigher = FALSE,plot=TRUE)
 #'
 #'im2=extract_pixels(im,target =MatrizSegmentada,valueTarget =1,
@@ -55,7 +67,7 @@
 #'
 #'#O canal Azul proporciona melhor segmentacao
 #'#O limiar pode ser um valor escolhido aleatoriamente (por exemplo: 0.6)
-#'MatrizSegmentada2=segmentation(b,treshold = 0.50,fillHull = TRUE,
+#'MatrizSegmentada2=segmentation(b,threshold = 0.60,fillHull = TRUE,
 #'selectHigher = TRUE,plot = TRUE)
 #'
 #'Medidas=measure_image(MatrizSegmentada2)
@@ -86,17 +98,17 @@
 #'
 #'#A banda de azul foi a que melhor discriminou #O limiar pode ser um valor
 #'#escolhido aleatoriamente (por exemplo: 0.6)
-#'MatrizSegmentada=segmentation(b,treshold = 0.6,fillHull = FALSE,
+#'MatrizSegmentada=segmentation(b,threshold = 0.6,fillHull = FALSE,
 #'selectHigher =FALSE,plot=TRUE)
 #'
 #'#O limiar tambem pode ser estabelecido pelo metodo de otsu
-#'MatrizSegmentada2=segmentation(b,treshold = "otsu",fillHull = TRUE,
+#'MatrizSegmentada2=segmentation(b,threshold = "otsu",fillHull = TRUE,
 #'selectHigher =FALSE,plot=TRUE)
 #'
 #'#Obter medidas de cada objeto
 #'medidas=measure_image(MatrizSegmentada2)
 #'#ver o numero de objetos e medias medidas
-#'
+#' medidas$ObjectNumber
 #'
 #'#Obter medidas de cada objeto excluindo o ruido
 #'medidas=measure_image(MatrizSegmentada2,noise = 1000) #numero de objetos
@@ -109,17 +121,16 @@
 #'#col="blue" ,plot = TRUE)
 #'
 #'
-#'#plot_meansures(im,medidas$measures[,1],coordy=medidas$measures[,2],
-#'#text=round(medidas$measures[,11],2),cex = 0.9,pathSave ="teste.jpg",
-#'#col="blue" ,plot=TRUE)
+#' plot_meansures(im,medidas$measures[,1],coordy=medidas$measures[,2],
+#' text=round(medidas$measures[,3],2),cex = 0.9,col="blue" ,plot=TRUE)
 #'##############################################################################
 #'#Convertendo a area dos objetos para cm2
 #'
 #'#Conhecendo o identificador do objeto de referencia
 #'
-#'#plot_meansures(im,medidas$measures[,1],coordy=medidas$measures[,2],
-#'#text=rownames(medidas$measures),cex= 0.9,pathSave ="teste.jpg",
-#'#col="blue",plot=TRUE )
+#' plot_meansures(im,medidas$measures[,1],coordy=medidas$measures[,2],
+#' text=rownames(medidas$measures),cex= 0.9,
+#' col="blue",plot=TRUE )
 
 #'#como pode-se ver, o objeto de referencia e o de numero 30
 #'# A area conhecida do objeto de referencia tem 8.5 x 5.5 cm.
@@ -153,54 +164,121 @@
 #'@export
 # @exportS3Method print measure_image
 
-measure_image=function(img,noise=0,id=NULL,length= NULL,width =NULL){
+measure_image=function(img,noise=0,id=NULL,length= NULL,
+                       width =NULL,splitConnected=FALSE,tolerance=1, ext=1,
+                       plot=TRUE){
   MatrizSegentada2=img
-  MatrizSegentada3=bwlabel(MatrizSegentada2)
-  res=computeFeatures.shape(MatrizSegentada3)
-  ID=res[,1]>noise
+  MatrizSegentada3=EBImage::bwlabel(MatrizSegentada2)
 
 
 
+  if(isTRUE(splitConnected)){
+  MatrizSegentada4=EBImage::watershed(EBImage::distmap(MatrizSegentada3), tolerance=tolerance, ext=ext)
+  }
 
-
-
-  if(nrow(res)>1){
-    #Exluir os ruidos
-
-    res2=res[ID,]
-
-    coord=computeFeatures.moment(MatrizSegentada3)
-    coord=coord[ID,]
-
-    RES=cbind(coord[,1:2],res2,coord[,3:5])
-
-    rownames(RES)=1:nrow(RES)
+  if(isFALSE(splitConnected)){
+    MatrizSegentada4=EBImage::watershed(MatrizSegentada3)
   }
 
 
-  if(nrow(res)==1){
-    #Exluir os ruidos
-    res2=res
+  Ta=table((MatrizSegentada4))
+  M=max(MatrizSegentada4)
+  res=table(MatrizSegentada4)[-1]
 
-    coord=computeFeatures.moment(MatrizSegentada3)
-    coord=coord
+  ID=res>noise
+  iddd=(0:M)[Ta>=noise]
+  `%ni%` <- Negate(`%in%`)
+  MatrizSegentada4[MatrizSegentada4 %ni% iddd]=0
 
-    RES=c(coord[1:2],res2,coord[3:5])
+
+
+
+
+  r=runif(M,0,1) ; g=runif(M,0,1) ; b=runif(M,0,1)
+  r=c(0,r); g=c(0,g); b=c(0,b)
+  arr=array(c(r[c(MatrizSegentada4)+1],g[c(MatrizSegentada4)+1],b[c(MatrizSegentada4)+1]),
+            dim = c(nrow(MatrizSegentada4),ncol(MatrizSegentada4),3))
+  arr=EBImage::as.Image(arr)
+  EBImage::colorMode(arr)=2
+
+
+  if(plot==TRUE){plot_image(arr)}
+
+
+
+
+
+  res=as.numeric(dimnames(res)$MatrizSegentada4)[ID]
+
+  RES=NULL
+   if(isTRUE(splitConnected)){
+
+  FFF=function(MatrizSegentada4,i){
+
+    coord=EBImage::computeFeatures.moment(MatrizSegentada4==i)
+    Medidas=EBImage::computeFeatures.shape(MatrizSegentada4==i)
+    r=c(coord[1:2],Medidas,coord[-c(1:2)])
+    r
+  }
+
+
+  NumberCores=detectCores()-1
+  cl <- parallel::makeCluster(NumberCores)
+  clusterExport(cl,
+                varlist = c("FFF","MatrizSegentada4","computeFeatures.shape","computeFeatures.moment"),
+                envir=environment())
+  on.exit(stopCluster(cl))
+
+
+
+  r <- parLapply(cl = cl,res, function(i){FFF(MatrizSegentada4,i)})
+
+ RES=matrix(unlist(r),ncol=11,byrow = TRUE)
+   }
+
+  if(isFALSE(splitConnected)){
+    coord=EBImage::computeFeatures.moment( EBImage::bwlabel(MatrizSegentada4!=0))
+    Medidas=EBImage::computeFeatures.shape( EBImage::bwlabel(MatrizSegentada4!=0))
+    ID=Medidas[,1]>noise
+    if(nrow(coord)==1){RES=(c(coord[,1:2],Medidas,coord[,-c(1:2)]))}
+    if(nrow(coord)>1){RES=(cbind(coord[,1:2],Medidas,coord[,-c(1:2)]))
+    RES=as.matrix(RES[ID,])}
+
+
+
+
+  }
+
+
+     if(is.matrix(RES)){
+  colnames(RES)=c( "m.cx"    ,  "m.cy" ,"s.area" ,"s.perimeter", "s.radius.mean"
+                   ,"s.radius.sd", "s.radius.min", "s.radius.max","m.majoraxis" ,"m.eccentricity"  ,   "m.theta")
+  rownames(RES)=1:nrow(RES)
+
+
+  }
+
+  if(!is.matrix(RES)){
     names(RES)=c( "m.cx"    ,  "m.cy" ,"s.area" ,"s.perimeter", "s.radius.mean"
-                  ,"s.radius.sd", "s.radius.min", "s.radius.max")
+                     ,"s.radius.sd", "s.radius.min", "s.radius.max","m.majoraxis" ,"m.eccentricity"  ,   "m.theta")
+
+
 
   }
 
-  RES2=RES
+
+
+RES=RES2=round(RES,3)
+
 
   if(is.matrix(id)){
     id2=id
     Area=length*width
     RES=RES2
-    RES[,3]= RES[,3]*Area/sum(id2)
-
-    perim=bwlabel(id)
-    perim2=computeFeatures.shape(perim)
+    if(nrow(RES)>1){RES[,3]= RES[,3]*Area/sum(id2)}
+    if(nrow(RES)==1){RES[3]= RES[3]*Area/sum(id2)}
+    perim=EBImage::bwlabel(id)
+    perim2=EBImage::computeFeatures.shape(perim)
 
     if(nrow(perim2)>1){
       perim3=perim2[perim[,1]==max(perim[,1]),2]
@@ -214,23 +292,21 @@ measure_image=function(img,noise=0,id=NULL,length= NULL,width =NULL){
 
 
   }
-  if(is.Image(id)){
+  if( EBImage::is.Image(id)){
     id2=id@.Data
     Area=length*width
     RES=RES2
     RES[,3]= RES[,3]*Area/sum(id2)
 
-    perim=bwlabel(perim)
-    perim=computeFeatures.shape(perim)
+    perim=EBImage::bwlabel(perim)
+    perim=EBImage::computeFeatures.shape(perim)
     perim2=perim[perim[,1]==max(perim[,1]),4]
 
     RES[,4:9]= RES[,4:9]*((length+width)*2 )/ perim2
 
 
   }
-
-
-  if((is.matrix(id)+is.Image(id))==0){
+  if((is.matrix(id)+ EBImage::is.Image(id))==0){
 
     if(isFALSE(is.null(id))){
 
@@ -262,7 +338,7 @@ RES[,4:9]= RES[,4:9]*((length+width)*2 )/ ((nrow(MatrizSegentada2)+ncol(MatrizSe
 
 
   #Verificando numero de objetos
-  ObjectNumber=nrow(res2)
+  ObjectNumber=nrow(RES)
 
   return(list(ObjectNumber=ObjectNumber,measures=RES))
 
