@@ -5,7 +5,7 @@ knitr::opts_chunk$set(
 )
 
 ## -----------------------------------------------------------------------------
-# library(EBImage)
+library(EBImage)
 library(ExpImage)
 
 ## -----------------------------------------------------------------------------
